#!/usr/bin/env python3
# (C) Copyright 2023 European Centre for Medium-Range Weather Forecasts.
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation
# nor does it submit to any jurisdiction.
from __future__ import annotations

from climetlab.decorators import normalize

from climetlab_wekeo_datasets.ecmwf.main import Main


class cams_global_reanalysis_eac4_monthly(Main):
    name = "EO:ECMWF:DAT:CAMS_GLOBAL_REANALYSIS_EAC4_MONTHLY"
    dataset = "EO:ECMWF:DAT:CAMS_GLOBAL_REANALYSIS_EAC4_MONTHLY"

    @normalize(
        "month",
        [
            "01",
            "02",
            "03",
            "04",
            "05",
            "06",
            "07",
            "08",
            "09",
            "10",
            "11",
            "12",
        ],
        multiple=True,
    )
    @normalize(
        "product_type",
        [
            "monthly_mean",
            "monthly_mean_by_hour_of_day",
        ],
        multiple=True,
    )
    @normalize(
        "time",
        [
            "00:00",
            "03:00",
            "06:00",
            "09:00",
            "12:00",
            "15:00",
            "18:00",
            "21:00",
        ],
        multiple=True,
    )
    @normalize(
        "variable",
        [
            "2m_dewpoint_temperature",
            "2m_temperature",
            "black_carbon_aerosol_optical_depth_550nm",
            "carbon_monoxide",
            "charnock",
            "dust_aerosol_0.03-0.55um_mixing_ratio",
            "dust_aerosol_0.55-0.9um_mixing_ratio",
            "dust_aerosol_0.9-20um_mixing_ratio",
            "dust_aerosol_optical_depth_550nm",
            "ethane",
            "formaldehyde",
            "geopotential",
            "hydrophilic_black_carbon_aerosol_mixing_ratio",
            "hydrophilic_organic_matter_aerosol_mixing_ratio",
            "hydrophobic_black_carbon_aerosol_mixing_ratio",
            "hydrophobic_organic_matter_aerosol_mixing_ratio",
            "hydroxyl_radical",
            "ice_temperature_layer_1",
            "isoprene",
            "leaf_area_index_high_vegetation",
            "leaf_area_index_low_vegetation",
            "mean_sea_level_pressure",
            "methane_chemistry",
            "nitric_acid",
            "nitrogen_dioxide",
            "nitrogen_monoxide",
            "organic_matter_aerosol_optical_depth_550nm",
            "ozone",
            "particulate_matter_10um",
            "particulate_matter_2.5um",
            "peroxyacetyl_nitrate",
            "potential_vorticity",
            "propane",
            "relative_humidity",
            "sea_ice_cover",
            "sea_salt_aerosol_0.03-0.5um_mixing_ratio",
            "sea_salt_aerosol_0.5-5um_mixing_ratio",
            "sea_salt_aerosol_5-20um_mixing_ratio",
            "sea_salt_aerosol_optical_depth_550nm",
            "sea_surface_temperature",
            "snow_albedo",
            "snow_density",
            "snow_depth",
            "so2_precursor_mixing_ratio",
            "soil_temperature_level_1",
            "specific_humidity",
            "sulphate_aerosol_mixing_ratio",
            "sulphate_aerosol_optical_depth_550nm",
            "sulphur_dioxide",
            "surface_pressure",
            "temperature",
            "temperature_of_snow_layer",
            "total_aerosol_optical_depth_550nm",
            "total_column_carbon_monoxide",
            "total_column_ethane",
            "total_column_formaldehyde",
            "total_column_hydroxyl_radical",
            "total_column_isoprene",
            "total_column_methane",
            "total_column_nitric_acid",
            "total_column_nitrogen_dioxide",
            "total_column_nitrogen_monoxide",
            "total_column_ozone",
            "total_column_peroxyacetyl_nitrate",
            "total_column_propane",
            "total_column_sulphur_dioxide",
            "total_column_water",
            "total_column_water_vapour",
            "vertical_velocity",
            "vertically_integrated_mass_of_dust_aerosol_0.03-0.55um",
            "vertically_integrated_mass_of_dust_aerosol_0.55-9um",
            "vertically_integrated_mass_of_dust_aerosol_9-20um",
            "vertically_integrated_mass_of_hydrophilic_black_carbon_aerosol",
            "vertically_integrated_mass_of_hydrophilic_organic_matter_aerosol",
            "vertically_integrated_mass_of_hydrophobic_black_carbon_aerosol",
            "vertically_integrated_mass_of_hydrophobic_organic_matter_aerosol",
            "vertically_integrated_mass_of_sea_salt_aerosol_0.03-0.5um",
            "vertically_integrated_mass_of_sea_salt_aerosol_0.5-5um",
            "vertically_integrated_mass_of_sea_salt_aerosol_5-20um",
            "vertically_integrated_mass_of_sulphate_aerosol",
            "vertically_integrated_mass_of_sulphur_dioxide",
        ],
        multiple=True,
    )
    @normalize(
        "year",
        [
            "2003",
            "2004",
            "2005",
            "2006",
            "2007",
            "2008",
            "2009",
            "2010",
            "2011",
            "2012",
            "2013",
            "2014",
            "2015",
            "2016",
            "2017",
            "2018",
            "2019",
            "2020",
            "2021",
            "2022",
            "2023",
        ],
        multiple=True,
    )
    @normalize("bbox", "bounding-box(list)")
    @normalize(
        "format_",
        [
            "grib",
            "netcdf",
        ],
    )
    @normalize(
        "model_level",
        [
            "60",
        ],
        multiple=True,
    )
    @normalize(
        "pressure_level",
        [
            "1",
            "2",
            "3",
            "5",
            "7",
            "10",
            "20",
            "30",
            "50",
            "70",
            "100",
            "150",
            "200",
            "250",
            "300",
            "400",
            "500",
            "600",
            "700",
            "800",
            "850",
            "900",
            "925",
            "950",
            "1000",
        ],
        multiple=True,
    )
    def __init__(
        self,
        month,
        product_type,
        time,
        variable,
        year,
        bbox=None,
        format_=None,
        model_level=None,
        pressure_level=None,
        limit=None,
    ):
        super().__init__(
            month=month,
            product_type=product_type,
            time=time,
            variable=variable,
            year=year,
            bbox=bbox,
            format_=format_,
            model_level=model_level,
            pressure_level=pressure_level,
            limit=limit,
        )
