#!/usr/bin/env python3
# (C) Copyright 2023 European Centre for Medium-Range Weather Forecasts.
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation
# nor does it submit to any jurisdiction.
from __future__ import annotations

from climetlab.decorators import normalize

from climetlab_wekeo_datasets.ecmwf.main import Main


class cems_fire_historical_v1(Main):
    name = "EO:ECMWF:DAT:CEMS_FIRE_HISTORICAL_V1"
    dataset = "EO:ECMWF:DAT:CEMS_FIRE_HISTORICAL_V1"

    @normalize(
        "dataset_type",
        [
            "consolidated_dataset",
            "intermediate_dataset",
        ],
    )
    @normalize(
        "day",
        [
            "01",
            "02",
            "03",
            "04",
            "05",
            "06",
            "07",
            "08",
            "09",
            "10",
            "11",
            "12",
            "13",
            "14",
            "15",
            "16",
            "17",
            "18",
            "19",
            "20",
            "21",
            "22",
            "23",
            "24",
            "25",
            "26",
            "27",
            "28",
            "29",
            "30",
            "31",
        ],
        multiple=True,
    )
    @normalize(
        "grid",
        [
            "0.25/0.25",
            "0.5/0.5",
            "original_grid",
        ],
    )
    @normalize(
        "month",
        [
            "01",
            "02",
            "03",
            "04",
            "05",
            "06",
            "07",
            "08",
            "09",
            "10",
            "11",
            "12",
        ],
        multiple=True,
    )
    @normalize(
        "product_type",
        [
            "ensemble_members",
            "reanalysis",
        ],
    )
    @normalize(
        "variable",
        [
            "build_up_index",
            "burning_index",
            "drought_code",
            "drought_factor",
            "duff_moisture_code",
            "energy_release_component",
            "fine_fuel_moisture_code",
            "fire_daily_severity_rating",
            "fire_danger_index",
            "fire_weather_index",
            "ignition_component",
            "initial_fire_spread_index",
            "keetch_byram_drought_index",
            "spread_component",
        ],
        multiple=True,
    )
    @normalize(
        "year",
        [
            "1940",
            "1941",
            "1942",
            "1943",
            "1944",
            "1945",
            "1946",
            "1947",
            "1948",
            "1949",
            "1950",
            "1951",
            "1952",
            "1953",
            "1954",
            "1955",
            "1956",
            "1957",
            "1958",
            "1959",
            "1960",
            "1961",
            "1962",
            "1963",
            "1964",
            "1965",
            "1966",
            "1967",
            "1968",
            "1969",
            "1970",
            "1971",
            "1972",
            "1973",
            "1974",
            "1975",
            "1976",
            "1977",
            "1978",
            "1979",
            "1980",
            "1981",
            "1982",
            "1983",
            "1984",
            "1985",
            "1986",
            "1987",
            "1988",
            "1989",
            "1990",
            "1991",
            "1992",
            "1993",
            "1994",
            "1995",
            "1996",
            "1997",
            "1998",
            "1999",
            "2000",
            "2001",
            "2002",
            "2003",
            "2004",
            "2005",
            "2006",
            "2007",
            "2008",
            "2009",
            "2010",
            "2011",
            "2012",
            "2013",
            "2014",
            "2015",
            "2016",
            "2017",
            "2018",
            "2019",
            "2020",
            "2021",
            "2022",
            "2023",
            "2024",
        ],
        multiple=True,
    )
    @normalize(
        "system_version",
        [
            "4_1",
        ],
        multiple=True,
    )
    @normalize("bbox", "bounding-box(list)")
    @normalize(
        "format_",
        [
            "grib",
            "netcdf",
        ],
        multiple=True,
    )
    def __init__(
        self,
        dataset_type,
        day,
        grid,
        month,
        product_type,
        variable,
        year,
        system_version="4_1",
        bbox=None,
        format_=None,
        limit=None,
    ):
        super().__init__(
            dataset_type=dataset_type,
            day=day,
            grid=grid,
            month=month,
            product_type=product_type,
            variable=variable,
            year=year,
            system_version=system_version,
            bbox=bbox,
            format_=format_,
            limit=limit,
        )
