#!/usr/bin/env python3
# (C) Copyright 2023 European Centre for Medium-Range Weather Forecasts.
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation
# nor does it submit to any jurisdiction.
from __future__ import annotations

from climetlab.decorators import normalize

from climetlab_wekeo_datasets.mercator.main import Main

LAYERS = [
    "cmems_mod_glo_phy-all_my_0.25deg_P1M-m_202311",  # noqa: E501 cmems_mod_glo_phy-all_my_0.25deg_P1M-m
    "cmems_mod_glo_phy-mnstd_my_0.25deg_P1D-m_202311",  # noqa: E501 cmems_mod_glo_phy-mnstd_my_0.25deg_P1D-m
    "cmems_mod_glo_phy-mnstd_my_0.25deg_P1M-m_202311",  # noqa: E501 cmems_mod_glo_phy-mnstd_my_0.25deg_P1M-m
]


class global_multiyear_phy_ens(Main):
    name = "EO:MO:DAT:GLOBAL_MULTIYEAR_PHY_ENS_001_031"
    dataset = "EO:MO:DAT:GLOBAL_MULTIYEAR_PHY_ENS_001_031"

    @normalize("layer", LAYERS)
    @normalize(
        "variables",
        [
            "mlotst_cglo",
            "mlotst_glor",
            "mlotst_mean",
            "mlotst_oras",
            "mlotst_std",
            "siconc_cglo",
            "siconc_glor",
            "siconc_mean",
            "siconc_oras",
            "siconc_std",
            "sithick_cglo",
            "sithick_glor",
            "sithick_mean",
            "sithick_oras",
            "sithick_std",
            "so_cglo",
            "so_glor",
            "so_mean",
            "so_oras",
            "so_std",
            "thetao_cglo",
            "thetao_glor",
            "thetao_mean",
            "thetao_oras",
            "thetao_std",
            "uo_cglo",
            "uo_glor",
            "uo_mean",
            "uo_oras",
            "uo_std",
            "vo_cglo",
            "vo_glor",
            "vo_mean",
            "vo_oras",
            "vo_std",
            "zos_cglo",
            "zos_glor",
            "zos_mean",
            "zos_oras",
            "zos_std",
        ],
        multiple=True,
    )
    @normalize("bbox", "bounding-box(list)")
    @normalize(
        "maximum_depth",
        [
            "-0.5057600140571594",
            "-1.5558552742004395",
            "-1045.854248046875",
            "-108.03028106689453",
            "-11.773679733276367",
            "-1151.9912109375",
            "-120",
            "-1265.8614501953125",
            "-13.99103832244873",
            "-133.07582092285156",
            "-1387.376953125",
            "-147.40625",
            "-1516.3636474609375",
            "-16.52532196044922",
            "-163.16445922851562",
            "-1652.5684814453125",
            "-1795.6707763671875",
            "-180.5499267578125",
            "-19.42980194091797",
            "-1945.2955322265625",
            "-199.7899627685547",
            "-2.6676816940307617",
            "-2101.026611328125",
            "-22.75761604309082",
            "-221.14117431640625",
            "-2262.421630859375",
            "-2429.025146484375",
            "-244.890625",
            "-26.558300018310547",
            "-2600.38037109375",
            "-271.35638427734375",
            "-2776.039306640625",
            "-2955.5703125",
            "-3.8562798500061035",
            "-30.874561309814453",
            "-300.88751220703125",
            "-3138.56494140625",
            "-3324.640869140625",
            "-333.8628234863281",
            "-35.740203857421875",
            "-3513.445556640625",
            "-370.6884765625",
            "-3704.65673828125",
            "-3897.98193359375",
            "-4093.15869140625",
            "-41.180023193359375",
            "-411.7938537597656",
            "-4289.95263671875",
            "-4488.15478515625",
            "-457.6256103515625",
            "-4687.5810546875",
            "-47.21189498901367",
            "-4888.06982421875",
            "-5.140361309051514",
            "-508.639892578125",
            "-5089.478515625",
            "-5291.68310546875",
            "-53.85063552856445",
            "-5494.5751953125",
            "-565.2922973632812",
            "-5698.060546875",
            "-5902.0576171875",
            "-6.543033599853516",
            "-61.11283874511719",
            "-628.0260009765625",
            "-69.02168273925781",
            "-697.2586669921875",
            "-77.61116027832031",
            "-773.3682861328125",
            "-8.09251880645752",
            "-856.678955078125",
            "-86.92942810058594",
            "-9.822750091552734",
            "-947.4478759765625",
            "-97.04131317138672",
        ],
    )
    @normalize(
        "minimum_depth",
        [
            "-0.5057600140571594",
            "-1.5558552742004395",
            "-1045.854248046875",
            "-108.03028106689453",
            "-11.773679733276367",
            "-1151.9912109375",
            "-120",
            "-1265.8614501953125",
            "-13.99103832244873",
            "-133.07582092285156",
            "-1387.376953125",
            "-147.40625",
            "-1516.3636474609375",
            "-16.52532196044922",
            "-163.16445922851562",
            "-1652.5684814453125",
            "-1795.6707763671875",
            "-180.5499267578125",
            "-19.42980194091797",
            "-1945.2955322265625",
            "-199.7899627685547",
            "-2.6676816940307617",
            "-2101.026611328125",
            "-22.75761604309082",
            "-221.14117431640625",
            "-2262.421630859375",
            "-2429.025146484375",
            "-244.890625",
            "-26.558300018310547",
            "-2600.38037109375",
            "-271.35638427734375",
            "-2776.039306640625",
            "-2955.5703125",
            "-3.8562798500061035",
            "-30.874561309814453",
            "-300.88751220703125",
            "-3138.56494140625",
            "-3324.640869140625",
            "-333.8628234863281",
            "-35.740203857421875",
            "-3513.445556640625",
            "-370.6884765625",
            "-3704.65673828125",
            "-3897.98193359375",
            "-4093.15869140625",
            "-41.180023193359375",
            "-411.7938537597656",
            "-4289.95263671875",
            "-4488.15478515625",
            "-457.6256103515625",
            "-4687.5810546875",
            "-47.21189498901367",
            "-4888.06982421875",
            "-5.140361309051514",
            "-508.639892578125",
            "-5089.478515625",
            "-5291.68310546875",
            "-53.85063552856445",
            "-5494.5751953125",
            "-565.2922973632812",
            "-5698.060546875",
            "-5902.0576171875",
            "-6.543033599853516",
            "-61.11283874511719",
            "-628.0260009765625",
            "-69.02168273925781",
            "-697.2586669921875",
            "-77.61116027832031",
            "-773.3682861328125",
            "-8.09251880645752",
            "-856.678955078125",
            "-86.92942810058594",
            "-9.822750091552734",
            "-947.4478759765625",
            "-97.04131317138672",
        ],
    )
    @normalize("end_datetime", "date(%Y-%m-%dT%H:%M:%S.%fZ)")
    @normalize("start_datetime", "date(%Y-%m-%dT%H:%M:%S.%fZ)")
    def __init__(
        self,
        layer,
        variables,
        bbox=None,
        maximum_depth=None,
        minimum_depth=None,
        end_datetime="2022-12-01T00:00:00Z",
        start_datetime="1993-01-01T00:00:00Z",
        limit=None,
    ):
        super().__init__(
            layer=layer,
            variables=variables,
            bbox=bbox,
            maximum_depth=maximum_depth,
            minimum_depth=minimum_depth,
            end_datetime=end_datetime,
            start_datetime=start_datetime,
            limit=limit,
        )
