#!/usr/bin/env python3
# (C) Copyright 2023 European Centre for Medium-Range Weather Forecasts.
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation
# nor does it submit to any jurisdiction.
from __future__ import annotations

from climetlab.decorators import normalize

from climetlab_wekeo_datasets.mercator.main import Main

LAYERS = [
    "cmems_obs-ins_glo_phy-temp-sal_nrt_oa_P1M_202211",  # noqa: E501 cmems_obs-ins_glo_phy-temp-sal_nrt_oa_P1M
]


class insitu_glo_phy_ts_oa_nrt(Main):
    name = "EO:MO:DAT:INSITU_GLO_PHY_TS_OA_NRT_013_002"
    dataset = "EO:MO:DAT:INSITU_GLO_PHY_TS_OA_NRT_013_002"

    @normalize(
        "variables",
        [
            "PSAL",
            "PSAL_ERR",
            "PSAL_PCTVAR",
            "TEMP",
            "TEMP_ERR",
            "TEMP_PCTVAR",
        ],
        multiple=True,
    )
    @normalize("layer", LAYERS)
    @normalize("bbox", "bounding-box(list)")
    @normalize(
        "maximum_depth",
        [
            "-1",
            "-3",
            "-5",
            "-10",
            "-15",
            "-20",
            "-25",
            "-30",
            "-35",
            "-40",
            "-45",
            "-50",
            "-55",
            "-60",
            "-65",
            "-70",
            "-75",
            "-80",
            "-85",
            "-90",
            "-95",
            "-100",
            "-110",
            "-120",
            "-130",
            "-140",
            "-150",
            "-160",
            "-170",
            "-180",
            "-190",
            "-200",
            "-210",
            "-220",
            "-230",
            "-240",
            "-250",
            "-260",
            "-270",
            "-280",
            "-290",
            "-300",
            "-310",
            "-320",
            "-330",
            "-340",
            "-350",
            "-360",
            "-370",
            "-380",
            "-390",
            "-400",
            "-410",
            "-420",
            "-430",
            "-440",
            "-450",
            "-460",
            "-470",
            "-480",
            "-490",
            "-500",
            "-510",
            "-520",
            "-530",
            "-540",
            "-550",
            "-560",
            "-570",
            "-580",
            "-590",
            "-600",
            "-610",
            "-620",
            "-630",
            "-640",
            "-650",
            "-660",
            "-670",
            "-680",
            "-690",
            "-700",
            "-710",
            "-720",
            "-730",
            "-740",
            "-750",
            "-760",
            "-770",
            "-780",
            "-790",
            "-800",
            "-820",
            "-840",
            "-860",
            "-880",
            "-900",
            "-920",
            "-940",
            "-960",
            "-980",
            "-1000",
            "-1020",
            "-1040",
            "-1060",
            "-1080",
            "-1100",
            "-1120",
            "-1140",
            "-1160",
            "-1180",
            "-1200",
            "-1220",
            "-1240",
            "-1260",
            "-1280",
            "-1300",
            "-1320",
            "-1340",
            "-1360",
            "-1380",
            "-1400",
            "-1420",
            "-1440",
            "-1460",
            "-1480",
            "-1500",
            "-1520",
            "-1540",
            "-1560",
            "-1580",
            "-1600",
            "-1620",
            "-1640",
            "-1660",
            "-1680",
            "-1700",
            "-1720",
            "-1740",
            "-1760",
            "-1780",
            "-1800",
            "-1820",
            "-1840",
            "-1860",
            "-1880",
            "-1900",
            "-1920",
            "-1940",
            "-1960",
            "-1980",
            "-2000",
        ],
    )
    @normalize(
        "minimum_depth",
        [
            "-1",
            "-3",
            "-5",
            "-10",
            "-15",
            "-20",
            "-25",
            "-30",
            "-35",
            "-40",
            "-45",
            "-50",
            "-55",
            "-60",
            "-65",
            "-70",
            "-75",
            "-80",
            "-85",
            "-90",
            "-95",
            "-100",
            "-110",
            "-120",
            "-130",
            "-140",
            "-150",
            "-160",
            "-170",
            "-180",
            "-190",
            "-200",
            "-210",
            "-220",
            "-230",
            "-240",
            "-250",
            "-260",
            "-270",
            "-280",
            "-290",
            "-300",
            "-310",
            "-320",
            "-330",
            "-340",
            "-350",
            "-360",
            "-370",
            "-380",
            "-390",
            "-400",
            "-410",
            "-420",
            "-430",
            "-440",
            "-450",
            "-460",
            "-470",
            "-480",
            "-490",
            "-500",
            "-510",
            "-520",
            "-530",
            "-540",
            "-550",
            "-560",
            "-570",
            "-580",
            "-590",
            "-600",
            "-610",
            "-620",
            "-630",
            "-640",
            "-650",
            "-660",
            "-670",
            "-680",
            "-690",
            "-700",
            "-710",
            "-720",
            "-730",
            "-740",
            "-750",
            "-760",
            "-770",
            "-780",
            "-790",
            "-800",
            "-820",
            "-840",
            "-860",
            "-880",
            "-900",
            "-920",
            "-940",
            "-960",
            "-980",
            "-1000",
            "-1020",
            "-1040",
            "-1060",
            "-1080",
            "-1100",
            "-1120",
            "-1140",
            "-1160",
            "-1180",
            "-1200",
            "-1220",
            "-1240",
            "-1260",
            "-1280",
            "-1300",
            "-1320",
            "-1340",
            "-1360",
            "-1380",
            "-1400",
            "-1420",
            "-1440",
            "-1460",
            "-1480",
            "-1500",
            "-1520",
            "-1540",
            "-1560",
            "-1580",
            "-1600",
            "-1620",
            "-1640",
            "-1660",
            "-1680",
            "-1700",
            "-1720",
            "-1740",
            "-1760",
            "-1780",
            "-1800",
            "-1820",
            "-1840",
            "-1860",
            "-1880",
            "-1900",
            "-1920",
            "-1940",
            "-1960",
            "-1980",
            "-2000",
        ],
    )
    @normalize("end_datetime", "date(%Y-%m-%dT%H:%M:%S.%fZ)")
    @normalize("start_datetime", "date(%Y-%m-%dT%H:%M:%S.%fZ)")
    def __init__(
        self,
        variables,
        layer="cmems_obs-ins_glo_phy-temp-sal_nrt_oa_P1M_202211",
        bbox=None,
        maximum_depth=None,
        minimum_depth=None,
        end_datetime="2024-05-01T00:00:00Z",
        start_datetime="2015-01-01T00:00:00Z",
        limit=None,
    ):
        super().__init__(
            variables=variables,
            layer=layer,
            bbox=bbox,
            maximum_depth=maximum_depth,
            minimum_depth=minimum_depth,
            end_datetime=end_datetime,
            start_datetime=start_datetime,
            limit=limit,
        )
