#!/usr/bin/env python3
# (C) Copyright 2023 European Centre for Medium-Range Weather Forecasts.
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation
# nor does it submit to any jurisdiction.
from __future__ import annotations

from climetlab.decorators import normalize

from climetlab_wekeo_datasets.mercator.main import Main

LAYERS = [
    "dataset-omega-3d-rep-weekly_202003",  # noqa: E501 dataset-omega-3d-rep-weekly
]


class multiobs_glo_phy_w_3d_rep(Main):
    name = "EO:MO:DAT:MULTIOBS_GLO_PHY_W_3D_REP_015_007"
    dataset = "EO:MO:DAT:MULTIOBS_GLO_PHY_W_3D_REP_015_007"

    @normalize(
        "variables",
        [
            "uago",
            "uo",
            "vago",
            "vo",
            "wo",
        ],
        multiple=True,
    )
    @normalize("layer", LAYERS)
    @normalize("bbox", "bounding-box(list)")
    @normalize(
        "maximum_depth",
        [
            "-100.25",
            "-1024.25",
            "-1056.5",
            "-1089.25",
            "-110.5",
            "-1122.5",
            "-1156.25",
            "-1190.5",
            "-12.5",
            "-121.25",
            "-1225.25",
            "-1260.5",
            "-1296.25",
            "-132.5",
            "-1332.5",
            "-1369.25",
            "-1406.5",
            "-144.25",
            "-1444.25",
            "-1482.5",
            "-156.5",
            "-16.25",
            "-169.25",
            "-182.5",
            "-196.25",
            "-2.5",
            "-20.5",
            "-210.5",
            "-225.25",
            "-240.5",
            "-25.25",
            "-256.25",
            "-272.5",
            "-289.25",
            "-30.5",
            "-306.5",
            "-324.25",
            "-342.5",
            "-36.25",
            "-361.25",
            "-380.5",
            "-4.25",
            "-400.25",
            "-42.5",
            "-420.5",
            "-441.25",
            "-462.5",
            "-484.25",
            "-49.25",
            "-506.5",
            "-529.25",
            "-552.5",
            "-56.5",
            "-576.25",
            "-6.5",
            "-600.5",
            "-625.25",
            "-64.25",
            "-650.5",
            "-676.25",
            "-702.5",
            "-72.5",
            "-729.25",
            "-756.5",
            "-784.25",
            "-81.25",
            "-812.5",
            "-841.25",
            "-870.5",
            "-9.25",
            "-90.5",
            "-900.25",
            "-930.5",
            "-961.25",
            "-992.5",
        ],
    )
    @normalize(
        "minimum_depth",
        [
            "-100.25",
            "-1024.25",
            "-1056.5",
            "-1089.25",
            "-110.5",
            "-1122.5",
            "-1156.25",
            "-1190.5",
            "-12.5",
            "-121.25",
            "-1225.25",
            "-1260.5",
            "-1296.25",
            "-132.5",
            "-1332.5",
            "-1369.25",
            "-1406.5",
            "-144.25",
            "-1444.25",
            "-1482.5",
            "-156.5",
            "-16.25",
            "-169.25",
            "-182.5",
            "-196.25",
            "-2.5",
            "-20.5",
            "-210.5",
            "-225.25",
            "-240.5",
            "-25.25",
            "-256.25",
            "-272.5",
            "-289.25",
            "-30.5",
            "-306.5",
            "-324.25",
            "-342.5",
            "-36.25",
            "-361.25",
            "-380.5",
            "-4.25",
            "-400.25",
            "-42.5",
            "-420.5",
            "-441.25",
            "-462.5",
            "-484.25",
            "-49.25",
            "-506.5",
            "-529.25",
            "-552.5",
            "-56.5",
            "-576.25",
            "-6.5",
            "-600.5",
            "-625.25",
            "-64.25",
            "-650.5",
            "-676.25",
            "-702.5",
            "-72.5",
            "-729.25",
            "-756.5",
            "-784.25",
            "-81.25",
            "-812.5",
            "-841.25",
            "-870.5",
            "-9.25",
            "-90.5",
            "-900.25",
            "-930.5",
            "-961.25",
            "-992.5",
        ],
    )
    @normalize("end_datetime", "date(%Y-%m-%dT%H:%M:%S.%fZ)")
    @normalize("start_datetime", "date(%Y-%m-%dT%H:%M:%S.%fZ)")
    def __init__(
        self,
        variables,
        layer="dataset-omega-3d-rep-weekly_202003",
        bbox=None,
        maximum_depth=None,
        minimum_depth=None,
        end_datetime="2018-12-26T00:00:00Z",
        start_datetime="1993-01-06T00:00:00Z",
        limit=None,
    ):
        super().__init__(
            variables=variables,
            layer=layer,
            bbox=bbox,
            maximum_depth=maximum_depth,
            minimum_depth=minimum_depth,
            end_datetime=end_datetime,
            start_datetime=start_datetime,
            limit=limit,
        )
